==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersCreatedAtArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersCreatedAtArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property dateRange A configuration block of the date range for the date filter. See date_range below for more details.
 * @property end An end date for the date filter. Required with `start` if `date_range` is not specified.
 * @property start A start date for the date filter. Required with `end` if `date_range` is not specified.
 */
public data class InsightFiltersCreatedAtArgs(
    public val dateRange: Output<InsightFiltersCreatedAtDateRangeArgs>? = null,
    public val end: Output<String>? = null,
    public val start: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersCreatedAtArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersCreatedAtArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersCreatedAtArgs.builder()
            .dateRange(dateRange?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .end(end?.applyValue({ args0 -> args0 }))
            .start(start?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersCreatedAtArgs].
 */
@PulumiTagMarker
public class InsightFiltersCreatedAtArgsBuilder internal constructor() {
    private var dateRange: Output<InsightFiltersCreatedAtDateRangeArgs>? = null

    private var end: Output<String>? = null

    private var start: Output<String>? = null

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("hagjuiwhgvlmjewj")
    public suspend fun dateRange(`value`: Output<InsightFiltersCreatedAtDateRangeArgs>) {
        this.dateRange = value
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("ldqggwkcjlohivpx")
    public suspend fun end(`value`: Output<String>) {
        this.end = value
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("rufmmkmliaulebgm")
    public suspend fun start(`value`: Output<String>) {
        this.start = value
    }

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("yuhdxtnlmncfskke")
    public suspend fun dateRange(`value`: InsightFiltersCreatedAtDateRangeArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dateRange = mapped
    }

    /**
     * @param argument A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("bomsbivdvxpbvqlc")
    public suspend
    fun dateRange(argument: suspend InsightFiltersCreatedAtDateRangeArgsBuilder.() -> Unit) {
        val toBeMapped = InsightFiltersCreatedAtDateRangeArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dateRange = mapped
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("mturiyjybkutqsgl")
    public suspend fun end(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("togojfwtwqswsxcl")
    public suspend fun start(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.start = mapped
    }

    internal fun build(): InsightFiltersCreatedAtArgs = InsightFiltersCreatedAtArgs(
        dateRange = dateRange,
        end = end,
        start = start,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersCreatedAtArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersCreatedAtArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property dateRange A configuration block of the date range for the date filter. See date_range below for more details.
 * @property end An end date for the date filter. Required with `start` if `date_range` is not specified.
 * @property start A start date for the date filter. Required with `end` if `date_range` is not specified.
 */
public data class InsightFiltersCreatedAtArgs(
    public val dateRange: Output<InsightFiltersCreatedAtDateRangeArgs>? = null,
    public val end: Output<String>? = null,
    public val start: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersCreatedAtArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersCreatedAtArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersCreatedAtArgs.builder()
            .dateRange(dateRange?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .end(end?.applyValue({ args0 -> args0 }))
            .start(start?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersCreatedAtArgs].
 */
@PulumiTagMarker
public class InsightFiltersCreatedAtArgsBuilder internal constructor() {
    private var dateRange: Output<InsightFiltersCreatedAtDateRangeArgs>? = null

    private var end: Output<String>? = null

    private var start: Output<String>? = null

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("tbmvrbrcjkrbsvnv")
    public suspend fun dateRange(`value`: Output<InsightFiltersCreatedAtDateRangeArgs>) {
        this.dateRange = value
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("cdyrbluwcxwkntwf")
    public suspend fun end(`value`: Output<String>) {
        this.end = value
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("qcibjhllidioqvek")
    public suspend fun start(`value`: Output<String>) {
        this.start = value
    }

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("mhwnkhbtjxqhflms")
    public suspend fun dateRange(`value`: InsightFiltersCreatedAtDateRangeArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dateRange = mapped
    }

    /**
     * @param argument A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("lllutwkwlavhhbrc")
    public suspend fun dateRange(argument: suspend InsightFiltersCreatedAtDateRangeArgsBuilder.() -> Unit) {
        val toBeMapped = InsightFiltersCreatedAtDateRangeArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dateRange = mapped
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("pvsgenhkirspbpom")
    public suspend fun end(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("shhloqdfnikmaawy")
    public suspend fun start(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.start = mapped
    }

    internal fun build(): InsightFiltersCreatedAtArgs = InsightFiltersCreatedAtArgs(
        dateRange = dateRange,
        end = end,
        start = start,
    )
}
